import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import {Tost} from "karaui";
import 'kara-module-img-view/lib/index.css'
import FileComponent from '../All/fileComponent/index'
import ImgComponent from '../All/imgComponent/index'
import TxtComponent from '../All/textComponent/index'
import LinkComponent from '../All/linkComponent/index'
import Nothing from "../../nothing/nothing";

@inject('FavoriteStore', 'ConfigStore')

@observer
class KaraMessage extends Component {
  constructor(props) {
    super(props)
  }

  onBottom = () => {
    let pn = this.props.FavoriteStore.messageList.pageNo + 1
    if (pn <= this.props.FavoriteStore.messageList.pageCount) {
      this.props.ConfigStore.config.httpAgent.post('/search/favor/favorMess', {
        keywords: this.props.keywords,
        isShowRich: 'true',
        pageInfo: {
          pageSize: this.props.FavoriteStore.messageList.pageSize,
          pageNo: pn
        }
      }).then(
        res => {
          if (res && res.resultCode && res.resultCode === '000000') {
            this.props.FavoriteStore.getMessageList(res, pn)
          }
          else {
            Tost({type: 'error', msg: '列表信息加载失败', time: 4})
          }
        }
      )
    }
  }

  componentDidMount() {
    this.props.ConfigStore.config.httpAgent.post('/search/favor/favorMess', {
      keywords: this.props.keywords,
      isShowRich: 'true',
      pageInfo: {
        pageSize: this.props.FavoriteStore.messageList.pageSize,
        pageNo: this.props.FavoriteStore.messageList.pageNo
      }
    }).then(
      res => {
        if (res && res.resultCode && res.resultCode === '000000') {
          this.props.FavoriteStore.getMessageList(res, this.props.FavoriteStore.messageList.pageNo)
        }
        else {
          Tost({type: 'error', msg: '列表信息加载失败', time: 4})
        }
      }
    )
  }

  componentWillReceiveProps(nextProps) {
    if (this.props.keywords != nextProps.keywords) {
      this.props.ConfigStore.config.httpAgent.post('/search/favor/favorMess', {
        keywords: nextProps.keywords,
        isShowRich: 'true',
        pageInfo: {
          pageSize: this.props.FavoriteStore.messageList.pageSize,
          pageNo: 1
        }
      }).then(
        res => {
          if (res && res.resultCode && res.resultCode === '000000') {
            this.props.FavoriteStore.getMessageList(res, this.props.FavoriteStore.messageList.pageNo)
          }
          else {
            Tost({type: 'error', msg: '列表信息加载失败', time: 4})
          }
        }
      )
    }
  }

  getDomByDataType = () => {
    const {ConfigStore, lang} = this.props
    const {karaui, httpAgent} = ConfigStore.config
    return this.props.FavoriteStore.messageList.result.map((i, k) => {
      if (i.type === 'PLAIN_MESSAGE') { //普通文本消息
        return <TxtComponent key={k} fileAttr={i} fromPage='message' lang={lang}
                             httpAgent={this.props.ConfigStore.config.httpAgent}
                             cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
                             cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite} karaui={karaui}/>
      }
      else if (i.type === 'EVENT_MESSAGE') { //文件消息
        if (i.fileType === 'rar' || i.fileType === 'zip' ||
          i.fileType === 'psd' || i.fileType === 'pdf' ||
          i.fileType === 'rp' || i.fileType === 'txt' ||
          i.fileType === 'exe' || i.fileType === 'tmp' ||
          i.fileType === 'ppt' || i.fileType === 'pptx' ||
          i.fileType === 'xls' || i.fileType === 'xlsx' ||
          i.fileType === 'doc' || i.fileType === 'docx') {
          return <FileComponent
            key={k}
            fileAttr={i}
            fromPage='message'
            contentRef={this.props.contentRef}
            lang={lang}
            karaui={karaui}
            httpAgent={httpAgent}
            cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
            cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
        }
        else if (i.fileType === 'jpg') {
          return <ImgComponent
            key={k}
            fileAttr={i}
            fromPage='message'
            contentRef={this.props.contentRef}
            imgViewList={this.props.FavoriteStore.imgViewList}
            lang={lang}
            karaui={karaui}
            httpAgent={httpAgent}
            cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
            cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
        }
      }
      else { // 富文本消息
        return <LinkComponent
          key={k}
          fileAttr={i}
          fromPage='message'
          lang={lang}
          karaui={karaui}
          httpAgent={httpAgent}
          cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
          cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
      }
    })
  }

  render() {
    const {ConfigStore, FavoriteStore, lang} = this.props;
    const {karaui: {Scroll}} = ConfigStore.config;
    if (this.props.FavoriteStore.messageList.result.length <= 0) {
      return <Nothing lang={lang}/>
    }
    return (
      <div className={css.KaraMessage} ref={this.contentRef}>
        <Scroll onScrollBottom={this.onBottom}>
          {this.getDomByDataType()}
        </Scroll>
      </div>
    )
  }
}

export default KaraMessage
