import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import KaraColleague from './Colleague/index'
import KaraNews from './News/index'
import KaraMessage from './Message/index'
import KaraAll from './All/index'

@inject('FavoriteStore')
@observer
class KaraFavorite extends Component {
  constructor(props) {
    super(props)
    this.state = {
      keywords: ''
    }
  }

  selectTab = (index) => {
    if (this.props.FavoriteStore.activeTab !== index) {
      this.props.FavoriteStore.setActiveTab(index)
    }
  }

  loadComponet() {
    const {FavoriteStore, lang} = this.props
    if (FavoriteStore.activeTab === 0) {
      return <KaraAll key='all' contentRef={this.props.contentRef} keywords={this.state.keywords} lang={lang}/>
    }
    else if (FavoriteStore.activeTab === 1) {
      return <KaraMessage key='message' contentRef={this.props.contentRef} keywords={this.state.keywords} lang={lang}/>
    }
    else if (FavoriteStore.activeTab === 2) {
      return <KaraNews key='news' keywords={this.state.keywords} lang={lang}/>
    }
    else if (FavoriteStore.activeTab === 3) {
      return <KaraColleague key='colleague' keywords={this.state.keywords} lang={lang}/>
    }
  }

  render() {
    const {FavoriteStore, lang} = this.props
    return (
      <div className={css.KaraFavorite}>
        <div className={`${css.tab} s-b-secondary`}>
          <ul className="s-bg-container">

            <li className={FavoriteStore.activeTab === 0 ? `s-primary s-b-primary ${css.active}` : ''} onClick={() => {
              this.selectTab(0)
            }}>
              {lang.all}
            </li>
            <li className={FavoriteStore.activeTab === 1 ? `s-primary s-b-primary ${css.active}` : ''} onClick={() => {
              this.selectTab(1)
            }}>
              {lang.chat}
            </li>
            <li className={FavoriteStore.activeTab === 2 ? `s-primary s-b-primary ${css.active}` : ''} onClick={() => {
              this.selectTab(2)
            }}>
              {lang.news}
            </li>
            <li className={FavoriteStore.activeTab === 3 ? `s-primary s-b-primary ${css.active}` : ''} onClick={() => {
              this.selectTab(3)
            }}>
              {lang.moments}
            </li>
          </ul>
          <div className={`${css.searchContainer} s-b-default`}>
            <input type='text' value={this.state.keywords} onChange={(e) => {
              this.setState({keywords: e.target.value})
            }}/>
            {this.state.keywords === '' ? <i className='kuc-iconfont kuc-search s-tips'/> : <i onClick={() => {
              this.setState({keywords: ''})
            }} className='kuc-iconfont kuc-planeticket_close s-tips'/>}
          </div>

        </div>

        <div className={`${css['result-content']} s-bg-container`}>
          {this.loadComponet()}
        </div>
      </div>
    )
  }
}

export default KaraFavorite
