import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import base64toblob from 'base64toblob'
import EXIF from 'exif-js'
import css from './index.scss'
import getInputFileUrl from '../../../util/getInputFileUrl'

@observer
class Avatar extends Component{
  constructor(props) {
    super(props)
    this.state = {
      originimg: { width: 0, height: 0 },
      zoomimg: { width: 0, height: 0 },
      drag: { width: 0, height: 0, top: 0, left: 0 },
      loading: true
    }
  }

  componentDidMount() {
    this.file = this.props.afile
    this.setOriginImgSrc() // 设置原图地址
  }

  setOriginImgSrc = () => {
    // 头像方向
    let orientation = 1
    let imageWidth = 0
    let imageHeight = 0
    const that = this
    EXIF.getData(this.file, function getData() {
      orientation = EXIF.getTag(this, 'Orientation') || 1
      imageWidth = EXIF.getTag(this, 'PixelXDimension')
      imageHeight = EXIF.getTag(this, 'PixelYDimension')
      that.originImgDom(that.file, orientation, imageWidth, imageHeight)
    })
  }

  mousedown = (e, direction) => {
    const { clientX, clientY } = e
    this.direction = direction
    const width = Number.parseInt(this.drag.style.width, 10)
    const top = Number.parseInt(this.drag.style.top, 10)
    const left = Number.parseInt(this.drag.style.left, 10)
    this.dragStar = { clientX, clientY, width, top, left }
  }

  mousemove = (e) => {
    const { clientX, clientY } = e
    if (this.direction === 'top') {
      const difference = this.dragStar.clientY - clientY
      const width = this.dragStar.width + difference
      const top = this.dragStar.top - difference
      const left = this.dragStar.left - (difference / 2)
      if (width >= this.state.zoomimg.width || width <= 40 || top <= 0 || left <= 0) return
      this.setState({
        drag: {
          width,
          top,
          left,
        },
      })
    }

    if (this.direction === 'topright') {
      const dy = this.dragStar.clientY - clientY
      const dx = clientX - this.dragStar.clientX
      const difference = Math.abs(dy) < Math.abs(dx) ? dy : dx
      const width = this.dragStar.width + difference
      const top = this.dragStar.top - difference
      const left = this.dragStar.left
      if (width <= 40 || top <= 0 || left + width >= this.state.zoomimg.width) return
      this.setState({
        drag: {
          width,
          top,
          left,
        },
      })
    }

    if (this.direction === 'right') {
      const difference = clientX - this.dragStar.clientX
      const width = this.dragStar.width + difference
      const top = this.dragStar.top - (difference / 2)
      const left = this.dragStar.left
      if (width >= this.state.zoomimg.height ||
        width + this.dragStar.left >= this.state.zoomimg.width ||
        width <= 40) return
      this.setState({
        drag: {
          width,
          top,
          left,
        },
      })
    }

    if (this.direction === 'rightbottom') {
      const dy = clientY - this.dragStar.clientY
      const dx = clientX - this.dragStar.clientX
      const difference = Math.abs(dy) < Math.abs(dx) ? dy : dx
      const width = this.dragStar.width + difference
      const top = this.dragStar.top
      const left = this.dragStar.left
      if (width <= 40 ||
        top + width >= this.state.zoomimg.height ||
        left + width >= this.state.zoomimg.width) return
      this.setState({
        drag: {
          width,
          top,
          left,
        },
      })
    }

    if (this.direction === 'bottom') {
      const difference = clientY - this.dragStar.clientY
      const width = this.dragStar.width + difference
      const top = this.dragStar.top
      const left = this.dragStar.left - (difference / 2)
      if (width >= this.state.zoomimg.width ||
        width + this.dragStar.top >= this.state.zoomimg.height ||
        width <= 40 ||
        left <= 0 ||
        left + width >= this.state.zoomimg.width) return
      this.setState({
        drag: {
          width,
          top,
          left,
        },
      })
    }

    if (this.direction === 'bottomleft') {
      const dy = clientY - this.dragStar.clientY
      const dx = this.dragStar.clientX - clientX
      const difference = Math.abs(dy) < Math.abs(dx) ? dy : dx
      const width = this.dragStar.width + difference
      const top = this.dragStar.top
      const left = this.dragStar.left - difference
      if (width <= 40 || top + width >= this.state.zoomimg.height || left <= 0) return
      this.setState({
        drag: {
          width,
          top,
          left,
        },
      })
    }

    if (this.direction === 'left') {
      const difference = this.dragStar.clientX - clientX
      const width = this.dragStar.width + difference
      const top = this.dragStar.top - (difference / 2)
      const left = this.dragStar.left - difference
      if (width >= this.state.zoomimg.height || width <= 40 || left <= 0) return
      this.setState({
        drag: {
          width,
          left,
          top,
        },
      })
    }

    if (this.direction === 'lefttop') {
      const dy = this.dragStar.clientY - clientY
      const dx = this.dragStar.clientX - clientX
      const difference = Math.abs(dy) < Math.abs(dx) ? dy : dx
      const width = this.dragStar.width + difference
      const top = this.dragStar.top - difference
      const left = this.dragStar.left - difference
      if (width <= 40 || left <= 0 || top <= 0) return
      this.setState({
        drag: {
          width,
          top,
          left,
        },
      })
    }

    if (this.direction === 'drag') {
      const dy = this.dragStar.clientY - clientY
      const dx = this.dragStar.clientX - clientX
      const width = this.dragStar.width
      let top = this.dragStar.top - dy
      let left = this.dragStar.left - dx

      if (top < 0) top = 0
      if (left < 0) left = 0
      if (top + width > this.state.zoomimg.height) top = this.state.zoomimg.height - width
      if (left + width > this.state.zoomimg.width) left = this.state.zoomimg.width - width

      this.setState({
        drag: {
          width,
          top,
          left,
        },
      })
    }
  }

  mouseup = () => {
    this.direction = undefined
  }

  inputFile = (e) => {
    this.file = e.target.files[0]
    const fileName = this.file.name
    const typeName = fileName.substring(fileName.lastIndexOf('.') + 1).toLocaleLowerCase()
    if (!(typeName === 'jpg' || typeName === 'bmp' || typeName === 'png' || typeName === 'jpeg')) {
      this.props.uploadImageTypeError()
      this.inputfile.value = null
      return
    }
    const fileSize = this.file.size
    if (fileSize / 1024 / 1024 > 10) {
      this.props.uploadImageSizeError()
      this.inputfile.value = null
      return
    }
    this.setOriginImgSrc() // 设置原图地址
    this.resetOriginimg() // 更改图片后重置原始图消息
    this.onLoading() // 更改图片后显示加载中
    // const url = getInputFileUrl(this.file)
    // this.originimg.setAttribute('src', url)
  }

  // 图片载入事件
  originimgload = () => {
    const originimg = this.originimg
    this.setState({
      originimg: {
        width: originimg.naturalWidth,
        height: originimg.naturalHeight,
      },
      zoomimg: {
        width: originimg.width,
        height: originimg.height,
      },
    })
    this.onLoadingEnd() // 加载完成
  }

  // 重置图片
  resetOriginimg = () => {
    this.setState({
      originimg: {
        width: 0,
        height: 0,
      },
      zoomimg: {
        width: 0,
        height: 0,
      },
    })
  }

  // 加载中
  onLoading = () => {
    this.setState({
      loading: true
    })
  }

  // 加载中end
  onLoadingEnd = () => {
    this.setState({
      loading: false
    })
  }

  dragDom = () => {
    const { width, height } = this.state.zoomimg
    const ruler = width > height ? height : width
    const dragruler = ruler * 0.8
    let mystyle
    if (this.direction) {
      mystyle = {
        width: this.state.drag.width,
        height: this.state.drag.width,
        top: this.state.drag.top,
        left: this.state.drag.left,
      }
    } else {
      mystyle = {
        width: dragruler,
        height: dragruler,
        top: (height - dragruler) / 2,
        left: (width - dragruler) / 2,
      }
    }

    return (<div
      ref={(e) => {
        this.drag = e
      }}
      className={css.drag}
      style={mystyle}
    >
      <div
        className={css.circle}
        onMouseDown={(e) => {
          this.mousedown(e, 'drag')
        }}
      >
        <i className={`${css.circlerow} ${css.first}`} />
        <i className={`${css.circlerow} ${css.toprightdot}`} />
        <i className={`${css.circlecall} ${css.first}`} />
        <i className={`${css.circlecall} ${css.toprightdot}`} />
      </div>
      <i
        className={`${css.dragdot} ${css.topdot}`}
        onMouseDown={(e) => {
          this.mousedown(e, 'top')
        }}
      />
      <i
        className={`${css.dragdot} ${css.toprightdot}`}
        onMouseDown={(e) => {
          this.mousedown(e, 'topright')
        }}
      />
      <i
        className={`${css.dragdot} ${css.rightdot}`}
        onMouseDown={(e) => {
          this.mousedown(e, 'right')
        }}
      />
      <i
        className={`${css.dragdot} ${css.rightbottomdot}`}
        onMouseDown={(e) => {
          this.mousedown(e, 'rightbottom')
        }}
      />
      <i
        className={`${css.dragdot} ${css.bottomdot}`}
        onMouseDown={(e) => {
          this.mousedown(e, 'bottom')
        }}
      />
      <i
        className={`${css.dragdot} ${css.bottomleftdot}`}
        onMouseDown={(e) => {
          this.mousedown(e, 'bottomleft')
        }}
      />
      <i
        className={`${css.dragdot} ${css.leftdot}`}
        onMouseDown={(e) => {
          this.mousedown(e, 'left')
        }}
      />
      <i
        className={`${css.dragdot} ${css.lefttopdot}`}
        onMouseDown={(e) => {
          this.mousedown(e, 'lefttop')
        }}
      />
    </div>)
  }

  /**
   * originimg 载入后 判断图片的形状做各种自适应
   * 通过用户在 originimg 的剪裁操作 获取剪裁数据
   * 创建canvas 把 originimg 和 剪裁数据给canvas
   * 获取canvas URL 给 viewimg 提供剪裁预览
   */
  viewimgDom = () => {
    const { width: originimgwidth } = this.state.originimg

    if (originimgwidth === 0) return null

    const { width: zoomimgwidth, height: zoomimgheight } = this.state.zoomimg

    const ruler = zoomimgwidth > zoomimgheight ? zoomimgheight : zoomimgwidth
    const dragruler = ruler * 0.8

    let { width: dragwidth, top: dragtop, left: dragleft } = this.state.drag

    if (dragwidth === 0) {
      dragwidth = dragruler
      dragtop = (zoomimgheight - dragruler) / 2
      dragleft = (zoomimgwidth - dragruler) / 2
    }

    const scale = zoomimgwidth / originimgwidth
    const imgviewwidth = dragwidth / scale

    this.canvas = document.createElement('canvas')
    const cvs = this.canvas
    cvs.width = 340
    cvs.height = 340
    const ctx = cvs.getContext('2d')
    ctx.drawImage(
      this.originimg,
      dragleft / scale,
      dragtop / scale,
      imgviewwidth,
      imgviewwidth,
      0, 0, 340, 340)
    const pic = cvs.toDataURL('image/png')
    return (<img
      ref={(e) => {
        this.viewimg = e
      }}
      src={pic}
      alt=""
    />)
  }

  /**
   * 获取用户选择图片的file
   * 获取图片的 exif 信息
   * 通过FileReader载入file获取base64
   * 创建img对象把base64给img对象
   * 创建canvas 把 img 给canvas
   * 开始各种旋转逻辑
   * 获取canvas url
   * 把canbas url 给 originimg 供用户剪裁
   */
  originImgDom = (file, orientation, imageWidth, imageHeight) => {
    const originimg = this.originimg
    let url = ''
    let width = 0
    let height = 0
    let deg = 0
    if (orientation === 1) {
      // 获取 input file url
      url = getInputFileUrl(file)
      // 展示图片
      originimg.setAttribute('src', url)
    } else {
      if (orientation === 3) {
        width = imageWidth
        height = imageHeight
        deg = 180
      } else if (orientation === 6) {
        width = imageHeight
        height = imageWidth
        deg = 90
      } else if (orientation === 8) {
        width = imageHeight
        height = imageWidth
        deg = -90
      }
      this.canvasOrigin = document.createElement('canvas')
      const cvs = this.canvasOrigin
      cvs.width = width
      cvs.height = height
      const ctx = cvs.getContext('2d')
      // 创建img对象给canvas drawImage
      const image = new Image()
      // 获取base64地址
      const reader = new FileReader()
      reader.readAsDataURL(file)
      reader.onload = (e) => {
        image.src = e.target.result
      }
      image.onload = () => {
        // 旋转canvas 并且 把图片放入canvas
        ctx.translate(parseInt(width / 2, 10), parseInt(height / 2, 10))
        ctx.rotate((deg * Math.PI) / 180)
        ctx.drawImage(
          image,
          0,
          0,
          imageWidth,
          imageHeight,
          0 - (imageWidth / 2),
          0 - (imageHeight / 2),
          imageWidth,
          imageHeight)
        // 获取canvas图片地址
        url = cvs.toDataURL('image/png')
        // 展示图片
        originimg.setAttribute('src', url)
      }
    }
  }

  /**
   * 获取用户剪裁的canvas
   * 获取canvas base 64
   * 通过base64 获取 二进制blob
   * 发送blob给后端
   */
  uploadAvatar = () => {
    const cvs = this.canvas
    let pic = cvs.toDataURL('image/png')
    pic = pic.replace(/^data:image\/(png|jpg);base64,/, '');
    const file = base64toblob(pic, 'image/png')
    this.props.uploadIcon(file)
  }

  render() {
    const loading = this.state.loading
    const zoomimgWidth = this.state.zoomimg.width
    const zoomimgHeight = this.state.zoomimg.height
    let originimgStyle = {}
    if (zoomimgWidth > 0 && zoomimgWidth < 160) {
      originimgStyle = {
        margin: `0 ${String(160 - zoomimgWidth) / 2}px`,
      }
    }
    if(zoomimgHeight > 0 && zoomimgHeight < 200) {
      originimgStyle = {
        margin: `${String(200 - zoomimgHeight) / 2}px 0`,
      }
    }
    if(loading) {
      originimgStyle = {
        height: '200px',
      }
    }
    return (<div className={css.setContainer}>
      <div
        className={`${css.setavatar} s-bg-container`}
        onMouseMove={(e) => {
          this.mousemove(e, 'top')
        }}
        onMouseUp={(e) => {
          this.mouseup(e, 'top')
        }}
      >
        <h1 className={css.title}>编辑个人头像</h1>
        <div className={`${css.set} ${css.c}`}>
          <div className={css.view}>
            <strong>预览</strong>
            <div className={css.avatarview}>
              {this.viewimgDom()}
              <i />
            </div>
            <span>340*340</span>
          </div>
          <div className={css.handdle}>
            <div
              ref={(e) => {
                this.origin = e
              }}
              className={css.originimg} style={originimgStyle}
            >
              <img
                ref={(e) => {
                  this.originimg = e
                }}
                alt=""
                onLoad={this.originimgload}
                style={{opacity: loading ? '0' : '100'}}
              />
              <span className={css.loading} style={{display: loading ? 'block' : 'none'}}>加载中...</span>
              <i className={css.originimgup} />
              {loading ? null : this.dragDom()}
            </div>
            <div className={css.uploadinfo}>
              <a>
                <span>选择文件</span>
                <input
                  ref={(e) => {
                    this.inputfile = e
                  }}
                  type="file"
                  onChange={(e) => {
                    this.inputFile(e)
                  }}
                />
              </a>
            </div>
          </div>
        </div>
        <div className={css.btns}>
          <a className={css.cancle} onClick={this.props.cancleAvatarFun}>取消</a>
          <a
            className={css.confirm}
            onClick={() => {
              this.uploadAvatar()
              this.props.modalHidden()
            }}
          >
            确认
          </a>
        </div>
      </div>
    </div>)
  }
}

export default Avatar
