/**
 * @module util/getInputFileUrl
 * @description 获取 input file url
 */
// URL对象上的createObjectURL方法调用得到的url
// 当不再需要这些 URL 对象时，每个对象必须通过调用 URL.revokeObjectURL() 方法来释放
// Blob转化为url的方式：
// 方法window.btoa(blob -> base64)再在前面拼接上data:${file.type};base64,
// btoa方法不可靠可以引用社区代码
export default function getInputFileUrl(file) {
  let url = null;
  if (window.createObjectURL !== undefined) { // basic
    url = window.createObjectURL(file);
  } else if (window.URL !== undefined) { // mozilla(firefox)
    url = window.URL.createObjectURL(file);
  } else if (window.webkitURL !== undefined) { // webkit or chrome
    url = window.webkitURL.createObjectURL(file);
  }
  return url;
}
